<h2>牙城-DB</h2>

<h3>DB</h3>

* PostgresHelper - contains all basic commands with logging. Select-command supports simple caching. Can be useful with
  any query language like Pypika.
* DatabaseError - simple DB exception.
* Singleton - simple implementation of singleton used in DB helper to prevent unnecessary propagation of connections. 